@@ -1,5 +1,5 @@
 use crate::context::Context;
-use crate::data::config::{Conf, NuConfig};
+use nu_data::config::{Conf, NuConfig};
 
 use crate::env::environment::{Env, Environment};
 use nu_source::Text;
@@ -30,6 +30,10 @@ impl EnvironmentSyncer {
         self.config = Arc::new(config);
     }
 
+    pub fn get_config(&self) -> Box<dyn Conf> {
+        self.config.clone().clone_box()
+    }
+
     pub fn load_environment(&mut self) {
         let config = self.config.clone();
 
@@ -128,9 +132,9 @@ impl EnvironmentSyncer {
 mod tests {
     use super::EnvironmentSyncer;
     use crate::context::Context;
-    use crate::data::config::tests::FakeConfig;
     use crate::env::environment::Env;
     use indexmap::IndexMap;
+    use nu_data::config::tests::FakeConfig;
     use nu_errors::ShellError;
     use nu_test_support::fs::Stub::FileWithContent;
     use nu_test_support::playground::Playground;
