@@ -17,7 +17,6 @@ mod cli;
 mod commands;
 mod completion;
 mod context;
-pub mod data;
 mod deserializer;
 mod documentation;
 mod env;
@@ -27,6 +26,7 @@ mod futures;
 mod git;
 mod keybinding;
 mod path;
+mod plugin;
 mod shell;
 mod stream;
 pub mod utils;
@@ -35,22 +35,22 @@ pub mod utils;
 mod examples;
 
 pub use crate::cli::{
-    cli, create_default_context, load_plugins, parse_and_eval, process_line,
-    run_pipeline_standalone, run_vec_of_pipelines, LineResult,
+    cli, create_default_context, parse_and_eval, process_line, run_pipeline_standalone,
+    run_vec_of_pipelines, LineResult,
 };
 pub use crate::commands::command::{
     whole_stream_command, CommandArgs, EvaluatedWholeStreamCommandArgs, Example, WholeStreamCommand,
 };
 pub use crate::commands::help::get_help;
 pub use crate::context::{CommandRegistry, Context};
-pub use crate::data::config;
-pub use crate::data::dict::TaggedListBuilder;
-pub use crate::data::primitive;
-pub use crate::data::value;
 pub use crate::env::environment_syncer::EnvironmentSyncer;
 pub use crate::env::host::BasicHost;
 pub use crate::prelude::ToOutputStream;
 pub use crate::stream::{InputStream, InterruptibleStream, OutputStream};
+pub use nu_data::config;
+pub use nu_data::dict::TaggedListBuilder;
+pub use nu_data::primitive;
+pub use nu_data::value;
 pub use nu_value_ext::ValueExt;
 pub use num_traits::cast::ToPrimitive;
 
