@@ -6,6 +6,7 @@ mod autoenv_untrust;
 mod cal;
 mod cd;
 mod compact;
+mod count;
 mod cp;
 mod default;
 mod drop;
@@ -20,6 +21,7 @@ mod group_by;
 mod headers;
 mod histogram;
 mod insert;
+mod into_int;
 mod is_empty;
 mod keep;
 mod last;
