@@ -32,16 +32,30 @@ fn figures_out_intelligently_where_to_write_out_with_metadata() {
 
 #[test]
 fn writes_out_csv() {
-    Playground::setup("save_test_2", |dirs, _| {
+    Playground::setup("save_test_2", |dirs, sandbox| {
+        sandbox.with_files(vec![FileWithContent(
+            "cargo_sample.json",
+            r#"
+            {
+                "package": {
+                        "name": "nu",
+                        "version": "0.14",
+                        "description": "A new type of shell",
+                        "license": "MIT",
+                        "edition": "2018"
+                }
+            }
+            "#,
+        )]);
+
         let expected_file = dirs.test().join("cargo_sample.csv");
 
         nu!(
             cwd: dirs.root(),
-            "open \"{}/cargo_sample.toml\" | get package | save save_test_2/cargo_sample.csv",
-            dirs.formats()
+            "open save_test_2/cargo_sample.json | get package | save save_test_2/cargo_sample.csv",
         );
 
         let actual = file_contents(expected_file);
-        assert!(actual.contains("nu,0.1.1,[Table],a new type of shell,ISC,2018"));
+        assert!(actual.contains("nu,0.14,A new type of shell,MIT,2018"));
     })
 }
